//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // config bits, constants, funcs for startup and UART

void __ISR(_TIMER_5_VECTOR, IPL4SOFT) Timer5ISR(void) {  // INT step 1: the ISR
  LATDINV = 0b10;                 // toggle RD1
  IFS0bits.T5IF = 0;              // clear interrupt flag
}

void __ISR(_TIMER_3_VECTOR, IPL3SOFT) Timer23ISR(void) { // INT step 1: the ISR
  char msg[100] = {};
  
  sprintf(msg,"The count was %u, or %10.8f seconds.\r\n", TMR2, TMR2/80000000.0);
  NU32_WriteUART1(msg);
  TMR2 = 0;                       // reset Timer23
  IFS0bits.T3IF = 0;              // clear interrupt flag
}

int main(void) {
  NU32_Startup();                 // cache on, interrupts on, LED/button init, UART init

  __builtin_disable_interrupts(); // INT step 2: disable interrupts

  TRISDbits.TRISD1 = 0;           // make D1 an output. connect D1 to C1/T2CK!

                                  // INT step 3
  T2CONbits.T32 = 1;              // for T23:    combine Timers 2 and 3 to make Timer23
  T2CONbits.TGATE = 1;            //             Timer23 in gated accumulation mode
  PR2 = 0xFFFFFFFF;               //             use the full period of Timer23
  T2CONbits.TON = 1;              //             turn Timer23 on 
  T4CONbits.T32 = 1;              // for T45:    enable 32 bit mode Timer45            
  PR4 = 79999999;                 //             set PR so timer rolls over at 1 Hz
  TMR4 = 0;                       //             initialize count to 0
  T4CONbits.TON = 1;              //             turn Timer45 on
  IPC5bits.T5IP = 4;              // INT step 4: priority for Timer5 (int for Timer45)
  IPC3bits.T3IP = 3;              //             priority for Timer3 (int for Timer23)
  IFS0bits.T5IF = 0;              // INT step 5: clear interrupt flag for Timer45
  IFS0bits.T3IF = 0;              //             clear interrupt flag for Timer23
  IEC0bits.T5IE = 1;              // INT step 6: enable interrupt for Timer45
  IEC0bits.T3IE = 1;              //             enable interrupt for Timer23
  __builtin_enable_interrupts();  // INT step 7: enable interrupts at the CPU
  while (1) {
    ;
  }
}
